#
# spec file for package pidgin-sipe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           pidgin-sipe
Version:        1.25.0
Release:        4.3
Summary:        Pidgin protocol plugin to connect to MS Skype for Business
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Instant Messenger
URL:            https://sipe.sourceforge.io/
Source:         http://downloads.sf.net/sipe/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE 0001-Fix-test-failures-with-appstream-1.0.patch christophe@krop.fr -- Fix test failures with appstream 1.0.
Patch0:         0001-Fix-test-failures-with-appstream-1.0.patch
# PATCH-FIX-OPENSUSE pidgin-sipe-fix-pointer-types.patch -- Fix pointer types.
Patch1:         pidgin-sipe-fix-pointer-types.patch
BuildRequires:  AppStream
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  pidgin
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(farstream-0.2)
BuildRequires:  pkgconfig(freerdp-shadow2)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmime-3.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-rtp-1.0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(nice) >= 0.1.13
BuildRequires:  pkgconfig(nss)
BuildRequires:  pkgconfig(purple) >= 2.0.12
BuildRequires:  pkgconfig(telepathy-glib) >= 0.24.0
Recommends:     freerdp
Recommends:     remmina

%description
A third-party plugin for the Pidgin multi-protocol instant
messenger. It implements the extended version of SIP/SIMPLE used by
various products:
 * Skype for Business.
 * Microsoft Office 365.
 * Microsoft Business Productivity Online Suite (BPOS).
 * Microsoft Lync Server.
 * Microsoft Office Communications Server (OCS 2007/2007 R2).
 * Microsoft Live Communications Server (LCS 2003/2005).
 * Reuters Messaging.

With this plugin you should be able to replace your
Skype for Business client with Pidgin.

%package -n pidgin-plugin-sipe
Summary:        Pidgin protocol plugin to connect to MS Skype for Business
Group:          Productivity/Networking/Instant Messenger
Requires:       libpurple-plugin-sipe = %{version}
%requires_ge    pidgin
Supplements:    (libpurple-plugin-sipe and pidgin)
# pidgin-sipe was last used in openSUSE Leap 42.2.
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
BuildArch:      noarch

%description -n pidgin-plugin-sipe
A third-party plugin for the Pidgin multi-protocol instant
messenger. It implements the extended version of SIP/SIMPLE used by
various products:
 * Skype for Business.
 * Microsoft Office 365.
 * Microsoft Business Productivity Online Suite (BPOS).
 * Microsoft Lync Server.
 * Microsoft Office Communications Server (OCS 2007/2007 R2).
 * Microsoft Live Communications Server (LCS 2003/2005).
 * Reuters Messaging.

With this plugin you should be able to replace your
Skype for Business client with Pidgin.

This package provides the icon set for Pidgin.

%package -n libpurple-plugin-sipe
Summary:        Libpurple third-party plugin for MS Skype for Business
Group:          Productivity/Networking/Instant Messenger
Recommends:     libpurple-plugin-sipe-lang
Enhances:       libpurple

%description -n libpurple-plugin-sipe
A third-party plugin for the libpurple multi-protocol instant
messaging library. It implements the extended version of SIP/SIMPLE
used by various products:
 * Skype for Business.
 * Microsoft Office 365.
 * Microsoft Business Productivity Online Suite (BPOS).
 * Microsoft Lync Server.
 * Microsoft Office Communications Server (OCS 2007/2007 R2).
 * Microsoft Live Communications Server (LCS 2003/2005).
 * Reuters Messaging.

%lang_package -n libpurple-plugin-sipe

%package -n telepathy-sipe
Summary:        MS Skype for Business connection manager for Telepathy
Group:          Productivity/Networking/Instant Messenger
# telepathy-plugin-sipe was last used in openSUSE Leap 42.2.
Provides:       telepathy-plugin-sipe = %{version}
Obsoletes:      telepathy-plugin-sipe < %{version}

%description -n telepathy-sipe
A third-party connection manager for the telepathy multi-protocol
instant messaging core. It implements the extended version of
SIP/SIMPLE used by various products:
 * Skype for Business.
 * Microsoft Office 365.
 * Microsoft Business Productivity Online Suite (BPOS).
 * Microsoft Lync Server.
 * Microsoft Office Communications Server (OCS 2007/2007 R2).
 * Microsoft Live Communications Server (LCS 2003/2005).
 * Reuters Messaging.

%prep
%autosetup -p1

%build
%configure \
  --disable-quality-check \
  --with-krb5             \
  --with-vv               \
  --with-appstream        \
  --enable-purple         \
  --enable-telepathy
%make_build check

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%check
%make_build check

%files -n pidgin-plugin-sipe
%license COPYING
%doc AUTHORS ChangeLog README TODO
%dir %{_datadir}/pixmaps/pidgin/
%dir %{_datadir}/pixmaps/pidgin/protocols/
%dir %{_datadir}/pixmaps/pidgin/protocols/*/
%{_datadir}/pixmaps/pidgin/protocols/*/sipe.*
%dir %{_datadir}/metainfo/
%{_datadir}/metainfo/pidgin-sipe.metainfo.xml

%files -n libpurple-plugin-sipe
%{_libdir}/purple-2/libsipe.so

%files -n libpurple-plugin-sipe-lang -f %{name}.lang

%files -n telepathy-sipe
%{_libexecdir}/telepathy-sipe
%{_datadir}/telepathy/
%{_datadir}/empathy/
%{_datadir}/dbus-1/services/org.freedesktop.Telepathy.ConnectionManager.sipe.service

%changelog
* Sat Dec 28 2024 Alexei Sorokin <sor.alexei@meowr.ru>
- Add pidgin-sipe-fix-pointer-types.patch: Fix pointer types.
- Add pidgin as a build requirement to fix "%%requires_ge pidgin".
* Wed Nov 22 2023 Christophe Marin <christophe@krop.fr>
- Add patch (boo#1217047):
  * 0001-Fix-test-failures-with-appstream-1.0.patch
* Mon Sep 20 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Tue Dec 10 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.25.0:
  * Provide idle start time for a buddy.
  * RTF support (incoming)
    + the code only extracts plain text from incoming RTF.
  * Fix build with glib-2.0 >= 2.62.0.
  * Inconsistent parsing of From:/To: headers.
  * Raise BR telepathy-glib >= 0.24.0.
  * Switch from GPLv2+ to SPDX identifier GPL-2.0-or-later.
- Drop openSUSE Leap 42.x support.
* Fri Nov 23 2018 fcrozat@suse.com
- Update to 1.24.0 (Application Sharing II):
  + Feature #104: Use user agent also for HTTP
  + Feature #6: Application Sharing Server (requires
    freerdp-shadow2)
  + add timeout handling for media streams
  + update AppStream handling
  + fix missing localisation in some code modules
  + debug log improvements
- Add BR pkgconfig(freerdp-shadow2) and AppStream for SLE15/Leap 15
  or later.
* Thu Oct 18 2018 fcrozat@suse.com
- Update to 1.23.3:
  + appshare: fix black screen with Remmina v1.2.0-rcgit.27
  + various minor fixes
  + fix compilation errors with libpurple 2.14.0 & GCC 8.0
- raise BR pkgconfig(nice) >= 0.1.13
- raise BR pkgconfig(purple) >= 2.0.12
* Tue Mar 13 2018 fcrozat@suse.com
- Update to 1.23.2:
  + fix some HTTP requests that were not sent
- Changes from version 1.23.1:
  + Fixed #337: Duplicate candidates in SDP
  + Fixed #336: Lync autodiscover does not follow user redirect
  + media: unconditionally ignore multichannel codecs
  + Updated translations.
- Changes from version 1.23.0:
  + Feature #100: Extend libpurple D-Bus interface
  + Feature #99: IPv6 addresses in SIP & SDP messages
  + don't load buddy photos from unknown sites by default
  * custom web URIs pose a security risk as they may be abused
  * users can override this behaviour in the account settings
  * Office365 accounts should not be affected by this change
  + add support for GMime 3.0 API
  + raise BR glib-2.0 >= 2.18.0
  + raise BR purple >= 2.7.0
  + drop support for GMime 2.4
  + drop support for gstreamer-0.10
* Tue Sep 12 2017 fcrozat@suse.com
- Update to 1.22.1:
  + Fixed #320: Multiple client detection broken
  + speed up Lync Autodiscover by using AccessLocation
  + purple: avoid rare SSL read deadlock
  + various minor fixes
  + crypto: make code compile with OpenSSL 1.1.0
  + drop references to Reuters Messaging
  - updated translations: Lithuanian (lt), Russian (ru), Swedish
    (sv), Turkish (tr)
* Wed Feb 15 2017 sor.alexei@meowr.ru
- Conditionalise video/audio to fix build on SLE 12 SP1.
* Wed Feb 15 2017 mrueckert@suse.de
- update to 1.22.0
  - Feature #93: Support for Lync Autodiscover (Stefan Becker)
  - Feature #6: Application Sharing Viewer (Jakub Adam)
  * requires libpurple >= 2.12.0
  * needs an external RDP client - remmina and xfreerdp are supported
  - Fixed #315: Crash when contact list is empty (Stefan Becker)
  - Fixed #314: sipe login problems with long pw (Stefan Becker)
  - separate logging and debugging output (Stefan Becker)
  * logging is always shown, e.g. in the Pidgin debug window
  * full message debugging now requires PURPLE_UNSAFE_DEBUG=1
  - new translations: Greek (el), Lithuanian (lt)
- drop pidgin-sipe-gstreamer-1.0.patch: no longer needed
- add recommends for remmina and freerdp so the desktop sharing
  stuff would work out of the box
- add BR for gstreamer-rtp-1.0 and farstream-0.2 to keep the
  video/audio feature working
* Fri Dec 16 2016 sor.alexei@meowr.ru
- Rename the pidgin-sipe package to pidgin-plugin-sipe.
- Rename the telepathy-plugin-sipe package to telepathy-sipe.
- Require Pidgin of the exact or greater version.
- Make pidgin-plugin-sipe noarch.
- Separate locales to libpurple-plugin-sipe-lang.
- Update description.
* Fri Jul  8 2016 tchvatal@suse.com
- Version update to 1.21.1:
  * various bug fixes in media support
  * configure no longer ignores CFLAGS/LDFLAGS/LIBS
- Drop telepathy conditionals as we don't build on sle11 anyway
- Move the docs from library to main package to allow multiple versions
  at once as SLP wants
* Fri Feb 12 2016 dimstar@opensuse.org
- Pass --disable-quality-check to configure: the 'quality' checks
  are a bunch of compiler flags like Werror and more warning. This
  is more important for development versions than for released
  ones.
* Wed Jan 13 2016 dimstar@opensuse.org
- Update to version 1.20.1:
  + Add support for another type of ADFS response.
  + Improve configure check for back-ported features.
  + Updated translations.
- Changes from version 1.20.0:
  + Parse HTML from Lync conference URL (Stefan Becker)
  + SRTP Support.
  + Office365 rejects RC4 in TLS-DSK: added support for
    AES-128/256-CBC.
- Drop patch: 0001-Fix-285-backport-for-1.18.x-1.19.x.patch
  Fixed upstream (bnc#965323).
* Tue Jun 30 2015 dimstar@opensuse.org
- Port to GStreamer 1.0 (follow pidin's port):
  + Add pidgin-sipe-gstreamer-1.0.patch
  + Replace pkgconfig(gstreamer-0.10) BuildRequires with
    pkgconfig(gstreamer-1.0).
  + Add autoreconf call, as the patch touches the buildsystem.
  + Pass --with-vv to configure, to ensure we do not lose Voice &
    Video support.
* Wed Apr  8 2015 tyang@suse.com
- Add patch: 0001-Fix-285-backport-for-1.18.x-1.19.x.patch
  Fixed both upstream and sled:
  sf#285: Office365 rejects RC4 in TLS-DSK.
  bnc#965323:Pidgin-sipe no longer works with Office 365 of
  skype for Business.
* Tue Apr  7 2015 dimstar@opensuse.org
- Update to version 1.19.1:
  + Fixed sf#278: 488 error after libnice upgrade.
  + Fix SIP re-authentication timeout to be max. 8 hours.
* Fri Feb 13 2015 zaitor@opensuse.org
- Update to version 1.19.0:
  + Move parsing of login name.
  + Support for Adium group chat bookmarks.
  + Support searching for SIP ID.
  + ADFS can't always be used for accounts that have Multi-Factor
    Authentication (MFA) enabled.
  + Support buddy photos from contactCard.
  + Fall back from Kerberos to NTLM.
  + Raised contact names.
  + Corrupted HTTP response crashes SIPE.
  + Fix calendar state machine when EWS URL is set.
  + Fall back to [MS-DLX] BasicSearch to improve search experience.
  + Implement search functionality for UCS.
  + adium:
  - Add chat room list UI.
  - Fix duplicate debug log messages.
  + Support for libnice TCP mode.
  + Refactor CCCP request code.
* Wed Dec 31 2014 jozef.koval03@gmail.com
- Update to version 1.18.5:
  + Redundant "const" breaks build with clang.
  + Purple idle-away converted to Away.
  + Svc: use authuser for RealmInfo request.
  + Adium: add release checking script.
  + Mingw: update fetch script to Pidgin 2.10.11.
  + Bugs fixed: sf#269, sf#276.
  + Updated translations.
* Tue Nov 11 2014 jozef.koval03@gmail.com
- Update to version 1.18.4:
  + ADFS fails when user and login name differ.
  + Adium: SIPE doesn't auto- or re-connect.
  + Fixed memory leaks.
  + Fixed processing of presence publish event response.
  + Fixed a longstanding issue that the Pidgin user status
    sometimes didn't switch back to "Available" after the end of a
    meeting.
  + Bugs fixed: sf#263, sf#264.
* Sat Aug 16 2014 dimstar@opensuse.org
- Update to version 1.18.3:
  + HTML response to EWS autodiscover triggers libxml2 assert.
  + V&V call gets rejected when IPv6 is enabled.
  + Windows 7: SIPE crashes after a minute.
  + mingw: improve crash information reporting.
  + Bugs fixed: sf#257, sf#258, sf#259.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 1.18.2:
  + ews: extract settings also from type EXPR.
  + ucs: honor user specified email URL.
  + adium: fix compilation on OS X 10.7.
  + Updated Transifex URLs.
  + Bugs fixed: sf#210, sf#241, sf#245, sf#248, sf#255.
  + Updated translations.
* Sun Apr 13 2014 zaitor@opensuse.org
- Update to version 1.18.1:
  + sf#238: Fixed false "not delivered" in conference.
  + sf#237: HTML escaping not removed from URL.
  + sf#210: Conference call ends with error message.
  + Fix endless loop with failed HTTP Basic authentication.
  + Fix crash when gstreamer nice plugin is missing.
  + Fix EWS autodiscover for some Office 365 users.
  + purple: fix missing "Copy to" in buddy menu.
  + purple/adium: ignore empty search values.
  + adium:
  - Fix group chat UI.
  - Implement BEAST mitigations for 10.8.5.
  + Add indication when user is connected from a mobile device.
  + Updated translations.
* Mon Jan 20 2014 zaitor@opensuse.org
- Update to version 1.18.0:
  + sf#71: Add support for EWS Autodiscover redirection.
  + sf#69: Add UI support for (group) chats. NOTE: Adium does not
    have an UI to fetch the room list.
  + sf#64: Add support for GSS-NTLMSSP.
  + sip-sec-krb5.c module has been renamed to sip-sec-gssapi.c if
    gssapi/gssapi_ntlmssp.h is detected then sip-sec-ntlm.c will be
    disabled and NTLM will be handled by sip-sec-gssapi.c instead.
    NOTE: at the time of this writing the user has to set up
    GSS-NTLMSSP by hand on his system, i.e. /etc/gss/mech.
  + Fixed sf#227: Adium client doesn't save email option settings.
  + Fixed sf#216: SIPE stops working on Mavericks.
  + Add an UI option to disable SSL BEAST mitigations NOTE:
    requires Adium 1.5.10.
  + Fixed sf#197: Account stays in connecting stage.
  + Cleanup for sip-sec Kerberos & SSPI modules.
  + Replace old TGT hack with gss_acquire_cred_with_password().
  + Clean up Kerberos detection in configure.
  + Remove special case handling; code is more straight-forward
    now.
  + Implement internal keepalive handling.
  + Implement crypto backend based on OpenSSL.
  + adium:
  - Xcode project files update.
  - Replace NSS crypto backend with OpenSSL.
* Mon Dec 23 2013 dimstar@opensuse.org
- Update to version 1.17.3:
  + Fixed sf#222: SIPE crashes when groupchat session expires.
  + Fixed sf#225: HTTP re-authentication with NTLM fails.
  + Fix UCS Persona key extraction.
* Sun Dec  8 2013 zaitor@opensuse.org
- Update to version 1.17.2:
  + Fixed sf#214: Typing notification does not always work.
  + Reverted one change which caused problems for some users.
  + Fixed sf#222: SIPE crashes when groupchat session expires.
  + Updated translations.
- Changes from version 1.17.1:
  + Fixed sf#215: Password not entity encoded in WSSE element.
  + Fixed sf#214: Typing notification does not always work.
  + Accept alternatives for webticket timestamp/keydata.
  + Adium: add "don't publish calendar" to account UI.
  + Contrib: add SSL BEAST mitigation patch for Adium.
  + Updated translations.
* Sun Sep 22 2013 zaitor@opensuse.org
- Update to version 1.17.0:
  + Feature sf#62: Support for Lync 2013 Unified Contact Store.
  + Feature sf#59: Support for Lync 2013 Persistent Chats
  + Fixed sf#211: Status "away" or "busy" incorrectly mapped to
    "Invisible".
  + Fixed sf#209: group chat doesn't like HTML.
  + Fixed sf#200: OCS archiving system blocks audio/video
    connection.
  + Fixed sf#187: Duplicate messages in group chat.
  + Fixed sf#184: Duplicate users showing in Group Chat.
  + Fix EWS autodiscover for Office 365.
  + Add support for group chat history.
  + Add support for buddy photos on Lync 2013.
* Tue Jul 16 2013 zaitor@opensuse.org
- Update to version 1.16.1:
  + sf#66: Windows DLL version information.
  + Fix call failure when host has multiple IP addresses.
  + Fix buddy list handling after moving to Lync 2013. Lync 2013
    migrates buddy list to Unified Contact Store (UCS). Note:
    modifying the buddy list is *NOT* supported yet!
  + Crash fixes for new HTTP stack.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 1.16.0:
  + sf#58: Implement Digest authentication scheme for SIP Proxy
    Authentication.
  + sf#196: Useragent value not forwarded to core.
  + sf#193: Pidgin Status changes stop working.
  + sf#186: Users appear offline when they are not.
  + Fix kinit-less use case with krb5 >= 1.11.
  + Rewritten HTTP stack from scratch:
  - cleaner, layered and hopefully less error-prone
    implementation.
  - HTTP stack internals no longer exposed to user code.
  - Reduced network traffic and less SSL handshakes by utilizing
    HTTP/1.1 connection keep alive for multiple HTTP requests to
    the same host.
  + Switch purple backend to deferred destruction approach:
  - Pidgin should no longer crash at connection close, even in
    corner cases.
  + Add menu entry to make a call with a phone number.
  + Some progress on telepathy backend.
  - Add TLS certificate accept/reject user interaction.
  - Add "Single Sign-On" & "Don't Publish Calendar" account
    options.
* Sat Apr 13 2013 dimstar@opensuse.org
- Update to version 1.15.1:
  + NOTE: SIPE SourceForge project got updated. Because of this all
    bug and feature request numbers have changed.
  + sf#190: SIP 407 response rejected with invalid message
    signature.
  + sf#189: Adium SIPE plugin vs. libpurple linking issues.
  + Fixed free-after-use issue that caused crashes for some users.
  + Fixed broken NTLM fallback in Negotiate.
  + Fixed subscriptions expiration by subscribing again after
    re-authentication.
  + Allow different user name and login for Office 365
    authentication.
  + Add SIPE version & git commit ID to debug log.
  + Added valgrind log analyzer script.
  + Added NTLM message anaylzer.
  + Updated Adium port.
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 1.15.0:
  + Support Kerberos for HTTP(S) authentication w/o SSPI
    (sf#3578135).
  + Add HTTPS to autodiscover probe (sf#3594094).
  + Simple button to disable calendar integration (sf#3607040).
  + Crash on 1.14.1 when connecting to server (sf#3603228).
  + sip uri with apostrophe is not valid (sf#3604671).
  + Fixed HTTP redirect crash.
  + Unified Single Sign-On handling in all places.
  + Added implementation for HTTP "WWW-Authenticate: Negotiate"
    scheme.
  + Enabled TLS-DSK support in Windows SSPI version.
  + TLS-DSK: don't ask for password if SSPI or Kerberos are
    compiled in.
  + Farstream 0.1.1 compatibility fix.
  + Support conf:sip: meeting URIs.
  + Updated Adium port.
* Tue Feb  5 2013 zaitor@opensuse.org
- Update to version 1.14.1:
  + Kerberos configuration should be passwordless (sf#3578132).
  - purple: non Single Sign-on users are asked for the password
    again.
  + Bug & memory leak fixes in sipe-buddy.c.
* Mon Dec 17 2012 dimstar@opensuse.org
- Update to version 1.14.0:
  + Add support for Web Ticket authentication using ADFS
    (sf#3585364).
  + Kerberos configuration should be passwordless (sf#3578132).
  + Connection drops after a few hours (sf#3580212)
  + Add support for buddy photos.
  + Add support for call to Audio Test Service.
  + Initial implementation for telepathy backend.
  + Reduce Web Ticket traffic by queueing requests & caching
    tickets.
  + Update OBS packaging information for Debian.
  + Various minor bug & build fixes.
* Sun Sep 16 2012 zaitor@opensuse.org
- Update to version 1.13.3:
  + Fixed OpenBSD build issue.
  + Support Lync 2010 meet URLs.
  + Revert to legacy MSOC protocol on Lync FT invitation.
  + Fix broken busy->available status switch.
  + Updated translations.
* Mon Apr  9 2012 dimstar@opensuse.org
- Update to version 1.13.1:
  + Detect incompatible encryption level with Lync
  + purple: add URI validity check to Add Buddy callback
  + Various build fixes
  + Updated translations.
- Drop pidgin-sipe-gcc47.patch: fixed upstream.
* Sat Mar 24 2012 dimstar@opensuse.org
- Add pidgin-sipe-gcc47.patch: Fix build with gcc 4.7; taken from
  git.
* Thu Mar 15 2012 vuntz@opensuse.org
- Update to version 1.13.0:
  + Added [MS-SIPAE] TLS-DSK authentication scheme:
  - TLS-DSK has been introduced in Lync
  - mandatory for Office365 accounts
  - also works for non-public Lync installations
  - does not work yet with SSPI on Windows
  + Added [MS-DLX] based Get Info/Contact Search:
  - [MS-PRES] SIP-Based Active Directory Search is disabled in
    Lync
  + Added experimental media TCP transport
  + Make it compile against the latest purple 3.0.x API
  + Make it compile against the latest glib2 2.31.x API
  + Completed cleanup: core no longer requires libpurple
  + Refactored crypto code, ie. NSS can replaced if necessary
  + Removed kopete backend: KDE is moving to telepathy
  + Build-related changes
- Drop pidgin-sipe-no-deprecated.patch: fixed upstream.
* Thu Jan 12 2012 dimstar@opensuse.org
- Change gmime-2_4-devel BuildRequires to gmime-devel. This rename
  happened long ago and was just a virtual provides by now.
- Drop checks for openSUSE 11.1.
* Mon Jan  9 2012 vuntz@opensuse.org
- Add pidgin-sipe-no-deprecated.patch: do not use deprecated glib
  API, to fix build on Factory.
* Fri Sep  2 2011 vuntz@opensuse.org
- Update to version 1.12.0:
  + Add support for OCS2007R2 Group Chat (sf#3064877)
  + Support for HTTP/1.1 Transfer-Encoding: chunked (sf##3311026)
  + Added MS TURN support
  + Implement timeouts for SIP request. Used for REGISTER
  + More work on Voice & Video call support
  + Add random Ms-Conversation-ID to INVITE
  + Fix parsing of P-Asserted-Identity header
  + Fix several crashes (including sf#3082602, sf#3148124,
    sf#3399007)
  + Fix several authenticfation issues (inclusing sf#2834758,
    sf#3090663, sf#3130915)
  + Make it compile against the purple 2.8.x & 3.0.x APIs
  + More internal changes to prepare for non-purple backends
  + Updated/add Adium and Miranda ports
  + Several build system fixes and improvements (including
    sf#3092324, sf#3150482, sf#3091490, sf#3108246)
  + Other bugs fixed: sf#3156430, sf#3161273, sf#3198585,
    sf#3267073.
- Drop pidgin-sipe-1.11.2-gcc46.patch: fixed upstream.
- Add pkgconfig(gstreamer-0.10) and pkgconfig(nice) BuildRequires
  on 12.1 and later (since 11.4 and earlier have a too old version
  of libnice), to build Voice & Video call support.
* Mon May 23 2011 idonmez@novell.com
- Add pidgin-sipe-1.11.2-gcc46.patch: remove write-only variables
  to fix compilation with gcc 4.6
* Thu Nov 18 2010 dimstar@opensuse.org
- Update to version 1.11.2:
  + Sipe-sign: fix parsing of P-Asserted-Identity header
  + Fixed memory leaks
  + sf#3090663: Re-authentication fails
  + sf#3091490: Make 1.11.0 Compile on FreeBSD
  + sf#3092324: Core dump in "make check"
- Changes from version 1.11.1:
  + sf#2834758: First NTLM signature check after startup fails
  + purple: fix memory leak in sipe_backend_transport_connect()
    error path
  + sf#3082602: Crash on Autodiscover
  + Build fixes.
* Sun Oct 17 2010 dimstar@opensuse.org
- Some simple preparations to enable telepathy plugin once it
  becomes available.
* Wed Oct  6 2010 john@redux.org.uk
- Update to version 1.11.0.
  + Feature sf#2945346 - added Lotus Notes/Domino Calendar
    integration.
  + Fixed sf#2971422: idle check for OCS2005 presence case (Stefan
    Becker)
  + Fixed sf#2982424: krb5 build errors on FreeBSD (Stefan Becker)
  + Fixed sf#2997639: pidgin crash after accepting cert (Stefan
    Becker)
  + Fixed sf#3001523: Cancelling a long pending file transfer
    crashes Pidgin (Jakub Adam)
  + Fixed sf#3002993: Group Name issues with ampersand (Stefan
    Becker)
  + Fixed sf#3029228: Calendar published at/with incorrect time
    (Stefan Becker)
  + Fixed sf#3029929: Crash with outlook 2k3 Calendar (Stefan
    Becker)
  + Fix logout from OCS (Jakub Adam)
  + Implement workaround for buddy list menu memory leaks
    (Stefan Becker)
  + Dropped UDP transport support (Stefan Becker)
  + Rewrote TCP & TLS transport support (Stefan Becker)
  + HTTP improvements: GET, cookies (pier11)
  + Alternative crypt/digest implementation based on NSS (pier11)
  + Rewrote message debug log and implemented an analyzer script
    for it (Stefan Becker)
  + More internal changes to prepare for non-purple backends
    (Stefan Becker)
  + New translation: Dutch (Flemish) 'nl' (fieona, ridiekel)
  + New translation: Swedish 'sv' (Rijad)
  + Added translations 'ar' 'hu' 'ja' 'ko' 'sv' 'zh_TW' submitted
    by Novell
  + New build option: nss/mozilla-nss/microb-engine-nss for
    non-purple backends
  + Add build option for kopete backend (Stefan Becker)
  + Updated Adium port (Emanuele Zattin)
* Tue Jun 29 2010 john@redux.org.uk
- Update to version 1.10.1
  + Fixed bug in the SIPE buddy list hash table functionality
    reported by a RHEL5 user.
  + Fixed Pidgin 2.7.0 API compatibility.
* Tue Jun 15 2010 john@redux.org.uk
- Fix openSUSE 11.1 build by removing unnecessary BuildRequires.
* Fri Jun  4 2010 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Apr  4 2010 pier11@operamail.com
- Update to version 1.10.0:
  + Feature sf#2823160: Access Levels (2007+ environment)
  + Feature sf#2957811: add support for "automaton" class
  + Feature sf#2972823: fail on in-line variable declarations
  + Fixed sf#2971422: handle OCS 2005 idiosyncrasy of varying SIP
    URI case
  + Fixed sf#2981563: Authentication protocol v4 - invalid
    signature of some incoming messages containing
    P-Asserted-Identity or P-Preferred-Identity with uppercased SIP
    or TEL in URI.
  + Fixed publication/"409 Conflict" endless looping
  + Prepare for Pidgin 2.7.0
  + Added SVG icon artwork
  + Many changes to configure script. Be sure to look at "configure
  - -help"
  + Many internal changes to prepare for non-purple backends
  + New build requirements: libxml2, glib-2.0 >= 2.12.0
  + New build option: gmime-2.4 >= 2.4.16 or gmime-2.6 >= 2.5.2 for
    non-purple backends
- Add BuildRequires: glib2-devel >= 2.12.0
- Add --enable-purple --disable-telepathy to configure
- Add %%check section.
- Add %%{_datadir}/pixmaps/pidgin/protocols/*/sipe.svg with
  workarounds for SLE11, openSUSE 11.0/1 don't have
  pidgin/protocols/scalable directory.
* Wed Mar 17 2010 dimstar@opensuse.org
- Update to version 1.9.1:
  + sf#2969327: Kerberos authentication always fails on *nix
    platforms
  + sf#2968287: Authentication failure in scenario when director
    server is Office Communications Server 2007 or above and home
    server is Live Communications Server 2005
  + Send BYE when response to IM message is 408/480/481
  + Re-enable offline status to be user settable.
* Wed Mar 10 2010 dimstar@opensuse.org
- Update to version 1.9.0:
  + Contributed File transfer functionality. File encryption is
    supported.
  + NTLMv2 and NTLMv2 Session Security support
  + Implemented SIP Authentication Extensions protocol version 4
    and 3
  + Adoption for commercial UNIX - HP/UX, Irix, Solaris - big
    endian fixes and build improvements
  + Packaged for Maemo platform (Nokia N900, etc.) at Maemo.org.
    Works with Pidgin from the same site.
  + Adoption of file transfer for Windows build
  + Official Debian package files in contrib
  + another shot at presence update problems
  + fix crash caused by uninitialized security contexts
  + Code analysis with Coverity Prevent.
  + Fix for "SIP/2.0 481 Call leg unavailable" error
  + Increased libpurple build requisite to >= 2.4.0
  + Updated translations.
* Thu Feb 18 2010 vuntz@opensuse.org
- Update to version 1.8.1:
  + Many crash fixes for error or corner cases in calendar
    integration
  + More detailed code analysis with Coverity Prevent
  + OpenSUSE Build Service configuration files
  + Fix NTLM crash if login setting is undefined
  + Use of g_str_has_prefix() available since glib 2.2 and
    null-safe
  + Build fixes for older OS releases.
* Thu Feb 11 2010 vuntz@opensuse.org
- Update to version 1.8.0:
  + Added integration with Exchange 2007/2010.
  + Added Calendar information to contact's tooltip.
  + 2005 presence engine has been completely rewritten, with new
    supported status.
  + Added "Accounts->{SIPE_ACCOUNT}->Status Reset" menu option to
    clean User Status set manually.
  + Added "Find on LinkedIn" link on contact's User Info screen.
  + Enhanced custom NTLM security provider to pass
    connection-oriented authentication.
  + Added Negotiate authentication scheme (Windows only).
  + Contributed code for Adium port.
  + Added Windows Messenger 5.0 (RTC/1.2) compatibility.
  + New BusyIdle status.
  + Fix memory leaks.
  + Fixed localization on Windows platform.
  + Fix bad rendering with html markup.
  + Fix broken federated contacts.
  + Fix for server auto-discovery
  + Fix for xdg-email invocation.
  + Fix for User Agent string.
  + Code: Take PURPLE_INIT_PLUGIN into use.
  + Various other fixes, including crashes and build fixes.
  + Updated translations.
* Sat Dec 26 2009 vuntz@opensuse.org
- Clean up packaging.
- Remove gconf_schemas_prereq macro, since there's nothing
  involving gconf.
- Rename purple-sipe subpackage to libpurple-plugin-sipe.
- Add pidgin BuildRequires for directory ownership.
- Add pidgin Requires for pidgin-sipe.
- Add libpurple Enhances for libpurple-plugin-sipe.
* Thu Nov 26 2009 john@redux.org.uk
- Update to version 1.7.1:
  + See ChangeLog for the full list of changes since version 1.3.3.
  + Support for Reuters Messaging environment.
  + Support for message formatting.
  + Invisible mode.
  + Full support for presence.
  + Better support of protocol.
  + New security framework.
  + Multi-party conversation.
  + Add telepathy-haze support.
  + Add integration with PBX (external phones).
  + New Idle status.
  + Many improvements and bug fixes.
  + Fix crashes.
  + Build fixes.
  + Updated translations.
- Split the package into pidgin-sipe and purple-sipe packages.
- Add gettext-devel, libtool BuildRequires.
- Remove pidgin, pidgin-devel, zlib-devel BuildRequires.
- Pass --with-krb5 to configure.
- Enable parallel build.
* Wed Sep 16 2009 crrodriguez@suse.de
- use find_lang macro
* Mon Feb  2 2009 gburt@suse.de
- Fix total loss of functionality if user was logged on in more than
  one location (bnc#459117)
* Thu Jan 22 2009 gburt@suse.de
- Patch fixing support for LCS 2005 buddy auth/blocking
- Fix logging in with TCP when no SRV records found
- Fix several crasher bugs
* Mon Jan  5 2009 gburt@suse.de
- Update to 1.3.3 which includes fixes for translation support,
  typos, crashes, and error handling.
* Tue Dec  9 2008 gburt@suse.de
- Remove -lang package, too late for package splits
* Sun Dec  7 2008 gburt@suse.de
- Create -lang package
* Sun Dec  7 2008 gburt@suse.de
- Fix a segfault, fix compatibility bug with OCS 2005 (not handling
  180 Ringing responses properly).
* Fri Dec  5 2008 gburt@suse.de
- Fix automatic support (redirecting) for LCS/OCS proxy servers,
  and show the user the error when 403 forbidden is received.
* Thu Dec  4 2008 gburt@suse.de
- Fix bugs with ability to set status, add support for setting a
  note (at least against some servers), fix OCS 2005 support, and
  improve account editing dialog to be more friendly, and improve
  error messages.
* Thu Dec  4 2008 gburt@suse.de
- Fix bugs with ability to add, modify, and remove contacts and
  groups.  Fix support for detecting contacts' away status, and
  to send them ours.  Fix support for saving and reading buddy
  aliases to/from the server.  Fix many crashes.
* Fri Nov 21 2008 gburt@suse.de
- Fix compatibility with Microsoft OCS 2007; 2-way IMing working
* Fri Nov  7 2008 gburt@suse.de
- Replace gz with bz2
* Fri Nov  7 2008 gburt@suse.de
- Update tarball with latest code from git plus a patch to get
    NTLM signing of messages working (eco#5322)
* Tue Sep  2 2008 gburt@suse.de
- Clarify and simplify the package description
* Mon Aug 11 2008 gburt@suse.de
- Initial package for pidgin-sipe
- SIPE 1.2
- http://sipe.sourceforge.net/
